@@ -7,7 +7,7 @@ use utf8;
 use Mojo::Base 'Mojolicious::Command';
 use String::Escape qw(qqbackslash);
 
-our $VERSION = 0.996;
+our $VERSION = 0.997;
 
 use File::Find;
 use Getopt::Long;
@@ -77,7 +77,8 @@ sub run {
         if ($language ne 'Skeleton') {
             if (lc $behavior eq 'save') {
                 %oldlex = eval {
-                    require "$app_class/I18N/$language.pm";
+                    local %INC = %INC;
+                    require $app->home->rel_file("lib/$app_class/I18N/$language.pm");
                     no strict 'refs';
                     %{*{"${app_klass}::I18N::${language}::Lexicon"}};
                 };
@@ -191,7 +192,7 @@ Tetsuya Tatsumi
 
 =head1 COPYRIGHT
 
-Copyright (C) 2015, Sergey Zasenko
+Copyright (C) 2011-2016, Sergey Zasenko
 
 This program is free software, you can redistribute it and/or modify it
 under the terms of the Artistic License version 2.0.
